package com.zhyc.module.produce.manage_sheep.service;

import java.util.List;
import com.zhyc.module.produce.manage_sheep.domain.ScChangeEar;

/**
 * 修改电子耳号记录Service接口
 * 
 * @author ruoyi
 * @date 2025-07-24
 */
public interface IScChangeEarService 
{
    /**
     * 查询修改电子耳号记录
     * 
     * @param id 修改电子耳号记录主键
     * @return 修改电子耳号记录
     */
    public ScChangeEar selectScChangeEarById(Integer id);

    /**
     * 查询修改电子耳号记录列表
     * 
     * @param scChangeEar 修改电子耳号记录
     * @return 修改电子耳号记录集合
     */
    public List<ScChangeEar> selectScChangeEarList(ScChangeEar scChangeEar);

    /**
     * 新增修改电子耳号记录
     * 
     * @param scChangeEar 修改电子耳号记录
     * @return 结果
     */
    public int insertScChangeEar(ScChangeEar scChangeEar);

    /**
     * 修改修改电子耳号记录
     * 
     * @param scChangeEar 修改电子耳号记录
     * @return 结果
     */
    public int updateScChangeEar(ScChangeEar scChangeEar);

    /**
     * 批量删除修改电子耳号记录
     * 
     * @param ids 需要删除的修改电子耳号记录主键集合
     * @return 结果
     */
    public int deleteScChangeEarByIds(Integer[] ids);

    /**
     * 删除修改电子耳号记录信息
     * 
     * @param id 修改电子耳号记录主键
     * @return 结果
     */
    public int deleteScChangeEarById(Integer id);

    List<String> searchEarNumbers(String query);
}
